From: Thomas Uhle <thomas.uhle@mailbox.tu-dresden.de>
To: 21988@debbugs.gnu.org
Subject: bug#21988: 24.5; keyword 'our' not being fontified in perl-mode
Date: Sun, 22 Nov 2015 16:38:01 +0100 (CET) [thread overview]
Message-ID: <alpine.LNX.2.00.1511221627190.21369@login2> (raw)
[-- Attachment #1: Type: TEXT/PLAIN, Size: 208 bytes --]
Hello,
the keyword 'our' opposed to the keywords 'my' and 'local' is not being
fontified in perl-mode. The simple patch that is attached to this bug
report is fixing this issue.
Best regards,
Thomas Uhle
[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: Type: TEXT/x-patch; name=perl-mode-elisp.diff, Size: 609 bytes --]
--- lisp/progmodes/perl-mode.el~ 2015-06-14 21:47:29 +0200
+++ lisp/progmodes/perl-mode.el 2015-11-22 16:01:26 +0100
@@ -194,8 +194,8 @@
"BEGIN" "END" "return" "exec" "eval") t)
"\\>")
;;
- ;; Fontify local and my keywords as types.
- ("\\<\\(local\\|my\\)\\>" . font-lock-type-face)
+ ;; Fontify local, my and our keywords as types.
+ ("\\<\\(local\\|my\\|our\\)\\>" . font-lock-type-face)
;;
;; Fontify function, variable and file name references.
("&\\(\\sw+\\(::\\sw+\\)*\\)" 1 font-lock-function-name-face)
reply other threads:[~2015-11-22 15:38 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
List information: https://www.gnu.org/software/emacs/
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=alpine.LNX.2.00.1511221627190.21369@login2 \
--to=thomas.uhle@mailbox.tu-dresden.de \
--cc=21988@debbugs.gnu.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
Code repositories for project(s) associated with this public inbox
https://git.savannah.gnu.org/cgit/emacs.git
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).